% Author jhoffman@eecs.berkeley.edu (Judy Hoffman)
% Implements the full multi-source domain adaptation system for use on
% heterogeneous source data.
%
% The system requires input source and target data with train and test
% splits. Additionally uses known training labels and if available test
% labels and source domain splits.
function [acc, pred, param_t_list] = ClassifyMultidomainData(data, labels, ...
    source_domains, param)
% Inputs:
%   data.train.source -  source training data (num_pts x num_features)
%   data.train.target - target training data (num_pts x num_features)
%   data.test.target - target test data (num_pts x num_features)
%   labels.train.source - source training labels (1 x num_pts)
%   labels.train.target - target training labels (1 x num_pts)
%   labels.test.target - target test labels (1 x num_pts)
%   source_domains - domain labels for the source training data (1xnum_pts)
%   param.C - C-svm parameter

if isempty(param.ECCV2010_releasePath)
    fprintf('Set the eccv 2010 code path before using this function\n');
    fprintf('The code from eccv 2010 can be downloaded from:\n');
    fprintf('\t\t http://www1.icsi.berkeley.edu/~saenko/projects.html#DA\n');
    return;
end
if isempty(param.LIBSVM_path)
    fprintf('Please set the libsvm path before using this function\n');
    return;
end
addpath(param.ECCV2010_releasePath);
addpath(param.LIBSVM_path);

%      Train Transformations from target to each source cluster     %
fprintf('Learning Transformations . . .\n');
param_t_list = LearnTransformations(data, labels, source_domains, param);

fprintf('Training Domain Classifier . . . \n');
%  Train Domain Classifier and Apply to Test Data to get Domain Weights   %
domain_weights = DomainWeightsPerTargetExample(data, source_domains, param);

disp('     Starting Classification');
%%% Unsupervised Method -- domain classifier %%%
[acc, pred] = MultisourceKnn(data, labels, domain_weights, ...
    source_domains, param_t_list, param);
end