function [acc, pred] = MultisourceKnn(data, labels, domain_weights, ...
    source_domains, param_t_list, param)
% compute domain specific similarity function for each test point
if param.held_out_categories
    tr_te_ind = labels.train.source > round(numel(param.categories)/2);
    Ytrain = labels.train.source(tr_te_ind);
    Xtrain = data.train.source(tr_te_ind,:);
else
    Xtrain = [data.train.source; data.train.target];
    Ytrain = [labels.train.source, labels.train.target];
end
num_tr = size(Xtrain,1);
num_te = size(data.test.target,1);

source_labels = unique(source_domains);
d = size(Xtrain,2);
K = zeros(num_tr, num_te);
for s = 1:numel(source_labels)
    param_t = param_t_list{s};
    S = param_t.S;
    Xlearn = param_t.Xlearn;

    L = eye(d) + Xlearn' * S * Xlearn;
    
    Ktrain_test = Xtrain * L * data.test.target';
    
    K = K + repmat(domain_weights(:,s)', num_tr, 1) .* Ktrain_test;
end
nKtest=ones(num_te,1);
nKtrain=ones(num_tr,1);
pred = kernelKNN(Ytrain, K', nKtrain, nKtest, 1)';
acc = 100 * sum(pred == labels.test.target) / num_te;
end