% Author: jhoffman@eecs.berkeley.edu (Judy Hoffman)
% Demo experiment running multi-domain adaptive classifier for unknown
% source domains. Using the Bing-Caltech256 dataset.

clear all;
addpath util
param = ConfigBingExperiment();

%                           Load data                                   %
dataset_dir = param.DATASET_path;
if isempty(dataset_dir)
    fprintf('Please set the directory path for the bing-caltech dataset\n');
    return;
end

categories = param.categories;

% Load Source Domain: Bing
disp('Loading Bing Data');
load(fullfile(dataset_dir, sprintf(param.fileName_bing, param.nttuse_bing)));
fstar = double(real(fstar>0));

ind = tr_label <= numel(param.categories);
data.train.source = NormalizeData(fstar(:,ind)', param.norm);
labels.train.source = tr_label(ind)';

clear fstar; clear tr_label;
clear fstar_test; clear te_label;

% Load Domain B: caltech256
disp('Loading CalTech256 Data');
load(fullfile(dataset_dir, sprintf(param.fileName_c256,param.nttuse_c256)));
fstar = double(real(fstar > 0));
fstar_test = double(real(fstar_test > 0));

if param.held_out_categories
    ind_tr = tr_label <= round(numel(param.categories)/2);
else
    ind_tr = tr_label <= numel(param.categories);
end
data.train.target = NormalizeData(fstar(:,ind_tr)', param.norm); 
labels.train.target = tr_label(ind_tr)';

ind_te = te_label <= numel(param.categories);
if param.held_out_categories
    ind_te = ind_te & te_label > round(numel(param.categories)/2);
end
data.test.target = NormalizeData(fstar_test(:,ind_te)', param.norm);
labels.test.target = te_label(ind_te)';

clear fstar; clear tr_label;
clear fstar_test; clear te_label;

% Knn - No adaptation no multisource baseline
ind = labels.train.source > round(numel(param.categories)/2);
[a, p] = KernelKnnClassify(labels.train.source(ind), data.train.source(ind,:), ...
    labels.test.target, data.test.target);
fprintf('Accuracy without adaptation = %6.2f\n',a);

% Cluster the source data into domains
tstart = tic;
fprintf('Domain Clustering into %d Domains . . .\n', param.num_clusters);
source_domains = DomainDiscovery (data.train.source, ...
    labels.train.source, param.num_clusters, [], param);
telapsed = toc(tstart);
fprintf('    Finished learning clusters in %6.2f s\n',telapsed);

% Classify target test data using known/clustered domain labels.
[acc, pred, param_t_list] = ClassifyMultidomainData(data, labels, ...
    source_domains, param);

fprintf('Accuracy without adaptation = %6.2f\n',a);
fprintf('Final Classification Accuracy = %6.2f\n',acc);

